@@ -1,4 +1,4 @@
-# Copyright © 2012-2016 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2012-2017 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -122,6 +122,7 @@ class Checker(object, metaclass=abc.ABCMeta):
         else:
             extension = '.' + self.options.file_type
         is_template = False
+        is_binary = False
         if extension == '.po':
             constructor = polib.pofile
         elif extension == '.pot':
@@ -129,6 +130,7 @@ class Checker(object, metaclass=abc.ABCMeta):
             is_template = True
         elif extension in ('.mo', '.gmo'):
             constructor = polib.mofile
+            is_binary = True
         else:
             self.tag('unknown-file-type')
             return
@@ -184,6 +186,7 @@ class Checker(object, metaclass=abc.ABCMeta):
         ctx = misc.Namespace()
         ctx.file = file
         ctx.is_template = is_template
+        ctx.is_binary = is_binary
         self.check_comments(ctx)
         self.check_headers(ctx)
         self.check_language(ctx)
@@ -588,6 +591,11 @@ class Checker(object, metaclass=abc.ABCMeta):
                 self.tag('duplicate-header-field-date', field)
                 dates = sorted(set(dates))
             elif len(dates) == 0:
+                if field.startswith('POT-') and ctx.is_binary:
+                    # In gettext >> 0.19.8.1, msgfmt will be removing
+                    # the POT-Creation-Date header.
+                    # https://savannah.gnu.org/bugs/?49654
+                    continue
                 self.tag('no-date-header-field', field)
                 continue
             for date in dates:
@@ -865,7 +873,7 @@ class Checker(object, metaclass=abc.ABCMeta):
                     self.tag('partially-translated-message', message_repr(message))
         if len(msgid_counter) == 0:
             possible_hidden_strings = False
-            if isinstance(ctx.file, polib.MOFile):
+            if ctx.is_binary:
                 possible_hidden_strings = ctx.file.possible_hidden_strings
             if not possible_hidden_strings:
                 self.tag('empty-file')
