@@ -86,16 +86,16 @@ def test_text():
 
 class test_types:
 
-    def t(self, s, type, warn_type=None, integer=False):
+    def t(self, s, tp, warn_type=None, integer=False):
         fmt = M.FormatString(s)
         [conv] = fmt
         assert_is_instance(conv, M.Conversion)
-        assert_equal(conv.type, type)
-        if type == 'void':
+        assert_equal(conv.type, tp)
+        if tp == 'void':
             assert_sequence_equal(fmt.arguments, [])
         else:
             [[arg]] = fmt.arguments
-            assert_equal(arg.type, type)
+            assert_equal(arg.type, tp)
         if warn_type is None:
             assert_sequence_equal(fmt.warnings, [])
         else:
@@ -159,6 +159,7 @@ class test_types:
         yield t, '%%', 'void'
 
     def test_c99_macros(self):
+        # pylint: disable=undefined-loop-variable
         def _t(s, tp):
             return self.t(s, tp, integer=True)
         def t(s, tp):
@@ -167,6 +168,7 @@ class test_types:
                 '%<{macro}>'.format(macro=s.format(c=c, n=n)),
                 ('u' if unsigned else '') + tp.format(n=n)
             )
+        # pylint: enable=undefined-loop-variable
         for c in 'diouxX':
             unsigned = c not in 'di'
             for n in {8, 16, 32, 64}:
